@@ -12,26 +12,41 @@ import { PreviewLaunchButton } from './deploy/PreviewLaunchButton';
 import { NotebookPanel } from '@jupyterlab/notebook';
 import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { OptumiMetadataTracker } from '../models/OptumiMetadataTracker';
-import { IntentSlider } from '../core';
+import { IntentSlider, SubHeader } from '../core';
 import { FilesPanel } from './deploy/FilesPanel';
 import { ResourcesPanel } from './deploy/resources/ResourcesPanel';
 import { LaunchMode } from './deploy/resources/LaunchMode';
 
+import ReactCardFlip from 'react-card-flip';
+import { IconButton } from '@material-ui/core';
+
+// import FlipCameraAndroidIcon from '@material-ui/icons/FlipCameraAndroid';
+import FlipIcon from '@material-ui/icons/Flip';
+import { PackageNotification } from './submit/PackageNotification';
+
 interface IProps {
 	style?: CSSProperties
 	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
-interface IState {}
-
-// Defaults for this component
-const DefaultState: IState = {}
+interface IState {
+	isFlipped:boolean
+}
 
 export class DeployPage extends React.Component<IProps, IState> {
-	state = DefaultState;
 	// We need to know if the component is mounted to change state
 	_isMounted = false;
 
+	constructor(props: IProps) {
+		super(props)
+		if (Global.tracker.currentWidget != null) {
+			Global.tracker.currentWidget.context.ready.then(() => {if (this._isMounted) this.forceUpdate()})
+		}
+		this.state = {
+			isFlipped: Global.manualModeSelected,
+		}
+	}
+
 	private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
@@ -45,16 +60,45 @@ export class DeployPage extends React.Component<IProps, IState> {
 		tracker.setMetadata(optumi);
 	}
 
-	constructor(props: IProps) {
-		super(props)
-		if (Global.tracker.currentWidget != null) {
-			Global.tracker.currentWidget.context.ready.then(() => {if (this._isMounted) this.forceUpdate()})
-		}
-	}
-
 	// The contents of the component
 	public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+		const flipCardHeader = (
+			<div style={{display: 'inline-flex', width: '100%'}}>
+				<SubHeader title='Resource Selection'/>
+				<span style={{
+					margin: 'auto 15px',
+					flexGrow: 1,
+					textAlign: 'end',
+					opacity: 0.5,
+					transitionDuration: '217ms',
+					whiteSpace: 'nowrap',
+					fontSize: '12px',
+					fontStyle: 'italic',
+				}}>
+					{this.state.isFlipped ? 'Manual' : 'Automatic'}
+				</span>
+				<IconButton
+					onClick={() => {
+						// We want to set the metadata back to the last history suggestion
+						// TODO:JJ This doesn't always work for some reason
+						setTimeout(() => {
+							const pack = Global.metadata.getLastPackage();
+							if (pack) {
+								const optumi = Global.metadata.getMetadata();
+								optumi.config = pack.optimizedConfig;
+								Global.metadata.setMetadata(optumi);
+							}
+						}, 250);
+						Global.manualModeSelected = !this.state.isFlipped;
+						this.safeSetState({ isFlipped: !this.state.isFlipped })
+					}}
+					style={{padding: '0px', marginRight: '-3px', width: '30px', height: '30px'}}
+					>
+					<FlipIcon style={{height: '20px'}}/>
+				</IconButton>
+			</div>
+		);
 		return (
 			<div style={Object.assign({overflow: 'auto'}, this.props.style)}>
 				{((Global.labShell.currentWidget instanceof NotebookPanel) && (Global.tracker.currentWidget != null) && (Global.tracker.currentWidget.context.isReady)) ? (
@@ -72,14 +116,40 @@ export class DeployPage extends React.Component<IProps, IState> {
 								<div style={{padding: '6px 10px'}}>
 									<FilesPanel openUserDialogTo={this.props.openUserDialogTo} />
 									<LaunchMode />
-									<ResourcesPanel />
-									<IntentSlider
-										color={'#10A0F9'}
-										getValue={this.getValue}
-										saveValue={this.saveValue}
-									/>
+
+									<ReactCardFlip
+										isFlipped={this.state.isFlipped}
+										flipSpeedBackToFront={0.3}
+										flipSpeedFrontToBack={0.3}
+									>
+										<div>
+											{flipCardHeader}
+											{!this.state.isFlipped && (
+												<>
+													<PreviewLaunchButton key={'preview-launch'}/>
+													<PackageNotification />
+												</>
+											)}
+										</div>
+
+										<div>
+											{flipCardHeader}
+											<ResourcesPanel />
+											<IntentSlider
+												color={'#10A0F9'}
+												getValue={this.getValue}
+												saveValue={this.saveValue}
+											/>
+											{this.state.isFlipped && (
+												<>
+													<PreviewLaunchButton key={'preview-launch'}/>
+													<PackageNotification />
+												</>
+											)}
+										</div>
+									</ReactCardFlip>
+
 								</div>
-								<PreviewLaunchButton style={{padding: '6px'}}/>
 							</>
 						)}
 					</>
@@ -95,6 +165,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 	handleLabShellChange = () => this.forceUpdate()
     handleTrackerChange = () => this.forceUpdate()
     handleMetadataChange = () => this.forceUpdate()
+	handlePackageChange = () => this.forceUpdate()
 	handleUserChange = () => {
 		this.forceUpdate()
 	}
@@ -106,6 +177,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 		Global.tracker.currentChanged.connect(this.handleTrackerChange);
         Global.tracker.selectionChanged.connect(this.handleTrackerChange);
         Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
+        Global.metadata.getPackageChanged().connect(this.handlePackageChange);
 		Global.onUserChange.connect(this.handleUserChange)
 		this.handleUserChange()
 	}
@@ -116,10 +188,33 @@ export class DeployPage extends React.Component<IProps, IState> {
 		Global.tracker.currentChanged.disconnect(this.handleTrackerChange);
         Global.tracker.selectionChanged.disconnect(this.handleTrackerChange);
         Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
+		Global.metadata.getPackageChanged().disconnect(this.handlePackageChange);
 		Global.onUserChange.disconnect(this.handleUserChange)
 		this._isMounted = false;
 	}
 
+	private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
+
 	public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
