@@ -7,17 +7,19 @@
 
 import { Button, Dialog, DialogContent, IconButton, Tab, Tabs, withStyles } from '@material-ui/core';
 import * as React from 'react';
-import MuiDialogTitle from '@material-ui/core/DialogTitle';
+import DialogTitle from '@material-ui/core/DialogTitle';
 import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import CloseIcon from '@material-ui/icons/Close';
 import { Global } from '../Global';
 import { ServerConnection } from '@jupyterlab/services';
-import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountGeneralSubMenu, AccountLimitsSubMenu, AccountPaymentSubMenu } from './settings/SettingsMenu';
+import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountPaymentSubMenu } from './settings/SettingsMenu';
 import { ShadowedDivider } from '../core';
 import { User } from '../models/User';
 import WarningPopup from '../core/WarningPopup';
 import { App } from '../models/application/App';
 
+import OpenInNewIcon from '@material-ui/icons/OpenInNew';
+
 const StyledDialog = withStyles({
     paper: {
         width: 'calc(min(80%, 600px + 150px + 2px))',
@@ -30,7 +32,7 @@ const StyledDialog = withStyles({
 })(Dialog);
 
 export const enum Page {
-    GENERAL = 0,
+    PREFERENCES = 0,
     LIMITS = 1,
     PAYMENT = 2,
     CONNECTORS = 3,
@@ -60,7 +62,7 @@ export class UserDialog extends React.Component<IProps, IState> {
         super(props);
 		this.state = {
             open: false,
-            selectedPanel: Page.GENERAL,
+            selectedPanel: Page.PREFERENCES,
             showLogoutWithSessionPopup: false,
             validPhoneNumber: true,
             showCloseWithInvalidNumberPopup: false,
@@ -77,7 +79,7 @@ export class UserDialog extends React.Component<IProps, IState> {
     
     private handleClickOpen = () => {
         if (this.props.onOpen) this.props.onOpen()
-		this.safeSetState({ open: true, selectedPanel: Page.GENERAL });
+		this.safeSetState({ open: true, selectedPanel: Page.PREFERENCES });
 	}
 
 	private handleClose = () => {
@@ -148,7 +150,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                     }}
                     scroll='paper'
 				>
-					<MuiDialogTitle
+					<DialogTitle
 					    disableTypography
                         style={{
                             display: 'inline-flex',
@@ -163,7 +165,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                             minWidth: '150px',
                             fontSize: '16px',
                             fontWeight: 'bold',
-                            paddingRight: '12px', // this is 6px counteracting the MuiDialogTitle padding and 6px aligning the padding to the right of the tabs
+                            paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
                             <div style={{margin: 'auto', paddingLeft: '12px'}}>
             					Settings
@@ -193,11 +195,21 @@ export class UserDialog extends React.Component<IProps, IState> {
                                     color: `error`,
                                 }}
                             />
+                            <Button 
+                                onClick={() => window.open('https://login.optumi.com/enduser/settings?iframe=true&iframeControlHideAll=true', '_blank')}
+                                disableElevation
+                                style={{ height: '36px', margin: '6px' }}
+                                variant="contained"
+                                color="primary"
+                                endIcon={<OpenInNewIcon/>}
+                            >
+                                Account
+                            </Button>
                             <Button
                                 disableElevation
                                 style={{ height: '36px', margin: '6px' }}
                                 variant="contained"
-                                color="secondary"
+                                color="primary"
                                 onClick={() => {
                                     const user: User = Global.user;
                                     if (user.appTracker.activeSessions.length != 0) {
@@ -255,7 +267,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 />
                             </IconButton>
                         </div>
-					</MuiDialogTitle>
+					</DialogTitle>
                     <ShadowedDivider />
                     <div style={{display: 'flex', height: 'calc(100% - 60px - 2px'}}>
                         <div style={{width: '150px'}}>
@@ -280,13 +292,13 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         style={{minHeight: '24px', flexGrow: 1}}
                                     >
                                         <Tab
-                                            label='GENERAL'
+                                            label='PREFERENCES'
                                             style={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
                                             }}
-                                            value={Page.GENERAL}
+                                            value={Page.PREFERENCES}
                                         />
                                         <Tab
                                             label='LIMITS'
@@ -354,9 +366,9 @@ export class UserDialog extends React.Component<IProps, IState> {
                                     // Height needs to be 100% otherwise it will cause problems with the phone number country selection
                                     display: 'flex', flexFlow: 'column', overflow: 'hidden', height: '100%'
                                 }}>
-                                    {this.state.selectedPanel == Page.GENERAL ? (
+                                    {this.state.selectedPanel == Page.PREFERENCES ? (
                                         <>
-                                            <div style={{display: 'flex', padding: '6px 6px 0px 6px', maxWidth: '450px'}}>
+                                            {/* <div style={{display: 'flex', padding: '6px 6px 0px 6px', maxWidth: '450px'}}>
                                                 <div style={{width: '68px', margin: '0px 6px'}}>
                                                     <div style={{
                                                         width: '48px',
@@ -373,7 +385,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                         {defaultProfilePicture}
                                                     </div>
                                                 </div>
-                                                <div style={{display: 'table', height: '48px', margin: '6px'}}>
+                                                <div style={{display: 'table', height: '48px', margin: '6px', flexGrow: 1}}>
                                                     <div style={{display: 'table-cell', verticalAlign: 'middle'}}>
                                                         <span style={{fontSize: '16px', lineHeight: '1', fontWeight: 'normal'}}>
                                                             {Global.user.name}
@@ -381,8 +393,8 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                         <br />
                                                     </div>
                                                 </div>
-                                            </div>
-                                            <AccountGeneralSubMenu
+                                            </div> */}
+                                            <AccountPreferencesSubMenu
                                                 style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
                                                 phoneValidOnBlur={(valid: boolean) => {
                                                     this.setState({ validPhoneNumber: valid });
