@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Switch } from '../../../core';
 import { Global } from '../../../Global';
-import { ComputeMetadata } from '../../../models/ComputeMetadata';
+import { ComputeConfig } from '../../../models/ComputeConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 
 interface IProps {
@@ -21,14 +21,14 @@ export class ComputeBasic extends React.Component<IProps, IState> {
     private getValue(): boolean {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
 		return compute.required;
 	}
 
 	private async saveValue(checked: boolean) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        const compute: ComputeMetadata = optumi.metadata.compute;
+        const compute: ComputeConfig = optumi.config.compute;
         compute.required = checked;
         tracker.setMetadata(optumi);
 	}
