@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../../../Global';
 
-import { GraphicsMetadata } from '../../../models/GraphicsMetadata';
+import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
@@ -24,14 +24,14 @@ export class GraphicsRating extends React.Component<IProps, IState> {
     private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const graphics: GraphicsMetadata = optumi.metadata.graphics;
+		const graphics: GraphicsConfig = optumi.config.graphics;
 		return graphics.rating[1];
 	}
 
 	private async saveValue(rating: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.rating = [-1, rating, -1];
 		tracker.setMetadata(optumi);
 	}
