@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Switch } from '../../../core';
 import { Global } from '../../../Global';
-import { MemoryMetadata } from '../../../models/MemoryMetadata';
+import { MemoryConfig } from '../../../models/MemoryConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 
 interface IProps {
@@ -22,14 +22,14 @@ export class MemoryBasic extends React.Component<IProps, IState> {
     private getValue(): boolean {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const memory: MemoryMetadata = optumi.metadata.memory;
+		const memory: MemoryConfig = optumi.config.memory;
 		return memory.required;
 	}
 
 	private async saveValue(checked: boolean) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         memory.required = checked;
         tracker.setMetadata(optumi);
 	}
