@@ -10,7 +10,7 @@ import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { MemoryMetadata } from '../../../models/MemoryMetadata';
+import { MemoryConfig } from '../../../models/MemoryConfig';
 import FormatUtils from '../../../utils/FormatUtils';
 
 interface IProps {
@@ -24,14 +24,14 @@ export class MemoryRating extends React.Component<IProps, IState> {
     private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         return memory.rating[1];
     }
     
     private async saveValue(rating: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         memory.rating = [-1, rating, -1];
         tracker.setMetadata(optumi);
     }
