@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { SubHeader } from '../../../core';
 import { Global } from '../../../Global';
-import { Expertise } from '../../../models/OptumiMetadata';
+import { Expertise } from '../../../models/OptumiConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { ComputeRating } from './ComputeRating';
 import { GraphicsRating } from './GraphicsRating';
@@ -40,10 +40,10 @@ export class Rating extends React.Component<IProps, IState> {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
         // Set all resource levels to basic
-        optumi.metadata.graphics.expertise = Expertise.RATING;
-        optumi.metadata.compute.expertise = Expertise.RATING;
-        optumi.metadata.memory.expertise = Expertise.RATING;
-        optumi.metadata.storage.expertise = Expertise.RATING;
+        optumi.config.graphics.expertise = Expertise.RATING;
+        optumi.config.compute.expertise = Expertise.RATING;
+        optumi.config.memory.expertise = Expertise.RATING;
+        optumi.config.storage.expertise = Expertise.RATING;
         tracker.setMetadata(optumi);
     }
 
