@@ -10,7 +10,7 @@ import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { ArrowBackIos } from '@material-ui/icons';
 import * as React from 'react'
 import { Global } from '../Global';
-import MuiDialogTitle from '@material-ui/core/DialogTitle';
+import DialogTitle from '@material-ui/core/DialogTitle';
 import { ShadowedDivider } from './ShadowedDivider';
 import { TextBox } from './TextBox';
 
@@ -175,7 +175,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                     open={this.state.open}
                     scroll='paper'
                 >
-                    <MuiDialogTitle
+                    <DialogTitle
                         disableTypography
                         style={{
                             display: 'inline-flex',
@@ -231,7 +231,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                                 </Button>
                             </ExtraInfo>
                         </div>
-                    </MuiDialogTitle>
+                    </DialogTitle>
                     <ShadowedDivider />
                     <DialogContent style={{ padding: '0px', display: 'flex' }}>
                         <div style={{ padding: '12px', display: 'flex', flexDirection: 'column' }}>
