@@ -41,7 +41,13 @@ export class NotificationContent extends React.Component<IProps, IState> {
             value: !value.notifications.jobFailedSMSEnabled || (value.notifications.jobFailedSMSEnabled && value.notifications.jobCompletedSMSEnabled) ?  VALUES[0].value : VALUES[1].value,
         }
     }
-    
+
+    private handleNotebookOptimizedSMSChange = (value: boolean) => {
+        const config = this.props.getValue().copy()
+        config.notifications.packageReadySMSEnabled = value;
+        this.props.saveValue(config);
+    }
+
     private handleJobStartedSMSChange = (value: boolean) => {
         const config = this.props.getValue().copy()
         config.notifications.jobStartedSMSEnabled = value;
@@ -60,6 +66,13 @@ export class NotificationContent extends React.Component<IProps, IState> {
         const disabled = !Global.user.notificationsEnabled || Global.user.phoneNumber == null || Global.user.phoneNumber == ""
         return (
             <>
+                <Switch
+                    getValue={() => (disabled && !this.props.disabled) ? false : this.props.getValue().notifications.packageReadySMSEnabled}
+                    saveValue={this.handleNotebookOptimizedSMSChange}
+                    label='Send a text when Optumi has a new optimization'
+                    labelWidth={LABEL_WIDTH}
+                    disabled={disabled || this.props.disabled || this.props.disabled}
+                />
                 <Switch
                     getValue={() => (disabled && !this.props.disabled) ? false : this.props.getValue().notifications.jobStartedSMSEnabled}
                     saveValue={this.handleJobStartedSMSChange}
@@ -95,7 +108,7 @@ export class NotificationContent extends React.Component<IProps, IState> {
                         </div>
                         <IconButton
                             onClick={() => {
-                                if (this.props.openUserDialogTo) this.props.openUserDialogTo(Page.GENERAL);
+                                if (this.props.openUserDialogTo) this.props.openUserDialogTo(Page.PREFERENCES);
                                 if (this.props.handleClose) this.props.handleClose();
                             }}
                             style={{
