@@ -324,7 +324,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         height: '24px',
                         margin: '0px 12px',
                         lineHeight: '24px',
-                        textAlign: 'center',
+                        // textAlign: 'center',
                     }}>
                         {this.renderLabel(showLabel)}
                         {this.renderPopupButton(showPopupButton)}
