@@ -43,9 +43,23 @@ export default class Editor extends React.Component<IProps, IState> {
                 />
             </div>
         ) : (
-            <div style={{whiteSpace: 'pre-wrap'}} className='p-Widget lm-Widget jp-Editor jp-CodeMirrorEditor jp-InputArea-editor'>
+            <div style={{
+                whiteSpace: 'pre-wrap',
+                fontFamily: 'var(--jp-code-font-family)',
+            }} className='p-Widget lm-Widget jp-Editor jp-CodeMirrorEditor jp-InputArea-editor'>
                 {this.props.cell.source}
             </div>
         )
     }
+
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
 }
\ No newline at end of file
