@@ -488,12 +488,12 @@ export class FileTracker {
 			init, 
 			settings
 		).then((response: Response) => {
+            Global.handleResponse(response);
 			if (this.polling) {
 				// If we are polling, send a new request in 30 seconds
                 if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
 				setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
 			}
-			Global.handleResponse(response);
 			return response.json();
 		}).then((body: any) => {
 			if (body) {
@@ -557,7 +557,11 @@ export class FileTracker {
                 this._filesChanged.emit();
 			}
         }, (error: ServerConnection.ResponseError) => {
-            setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
+            if (this.polling) {
+				// If we are polling, send a new request in 30 seconds
+                if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
+				setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
+			}
         });
     }
 
