@@ -11,10 +11,12 @@ export class NotificationConfig {
     public jobStartedSMSEnabled: boolean;
     public jobCompletedSMSEnabled: boolean;
     public jobFailedSMSEnabled: boolean;
+    public packageReadySMSEnabled: boolean;
 
     constructor(map: any = {}, user: User = null) {
         this.jobStartedSMSEnabled = map.jobStartedSMSEnabled || false;
         this.jobCompletedSMSEnabled = map.jobCompletedSMSEnabled || false;
         this.jobFailedSMSEnabled = map.jobFailedSMSEnabled || false;
+        this.packageReadySMSEnabled = map.packageReadySMSEnabled || false;
     }
 }
\ No newline at end of file
