@@ -43,35 +43,40 @@ export default class FileServerUtils {
 
 	public static async getRecursiveTree(fileName: string): Promise<FileMetadata[]> {
 		var files: FileMetadata[] = [];
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "api/contents/" + fileName;
-		const response = ServerConnection.makeRequest(
-			url, 
-			{}, 
-			settings
-		).then((response: Response) => {
-			if (response.status !== 200 && response.status !== 201) {
-				throw new ServerConnection.ResponseError(response);
-			}
-			return response.json();
-		});
-		const body = (await response);
-
-		if (body.type == 'directory') {
-			const promises: Promise<FileMetadata[]>[] = [];
-			for (var file of body.content) {
-				if (file.type == 'directory') {
-					// TODO:JJ This is a problem when we have a large number of files
-					promises.push(this.getRecursiveTree(file.path));
-				} else {
-					files.push(file as FileMetadata);
+		try {
+			const settings = ServerConnection.makeSettings();
+			const url = settings.baseUrl + "api/contents/" + fileName;
+			const response = ServerConnection.makeRequest(
+				url, 
+				{}, 
+				settings
+			).then((response: Response) => {
+				if (response.status !== 200 && response.status !== 201) {
+					throw new ServerConnection.ResponseError(response);
 				}
+				return response.json();
+			});
+			const body = (await response);
+
+			if (body.type == 'directory') {
+				const promises: Promise<FileMetadata[]>[] = [];
+				for (var file of body.content) {
+					if (file.type == 'directory') {
+						// TODO:JJ This is a problem when we have a large number of files
+						promises.push(this.getRecursiveTree(file.path));
+					} else {
+						files.push(file as FileMetadata);
+					}
+				}
+				for (var promise of promises) {
+					files = files.concat(await promise);
+				}
+			} else {
+				files.push(body as FileMetadata);
 			}
-			for (var promise of promises) {
-				files = files.concat(await promise);
-			}
-		} else {
-			files.push(body as FileMetadata);
+		} catch ( err) {
+			console.warn("Encountered error wile getting directory contents for " + fileName)
+			console.warn(err)
 		}
 		return files;
 	}
